i static method

int i(
  1. String tag,
  2. String msg
)

Send an info log message.

  • tag Used to identify the source of a log message. It usually identifies the class or activity where the log call occurs. This value may be null.
  • msg The message you would like logged. This value may be null.

return a positive value if the message was loggable (see isLoggable).

Implementation

static int i(String tag, String msg) {
  return $p.Log.i(tag.toJString(), msg.toJString());
}