println static method

int println(
  1. int priority,
  2. String tag,
  3. String msg
)

Low-level logging call.

  • priority int: The priority/type of this log message Value is assert_, error, warn, info, debug, or verbose
  • tag Used to identify the source of a log message. It usually identifies the class or activity where the log call occurs. This value may be null.
  • message String: The message you would like logged. This value cannot be null.

return a positive value if the message was loggable isLoggable.

Implementation

static int println(int priority, String tag, String msg) {
  return $p.Log.println(priority, tag.toJString(), msg.toJString());
}