v static method

int v(
  1. String tag,
  2. String msg
)

Send an verbose log message.

  • tag Used to identify the source of a log message. It usually identifies the class or activity where the log call occurs. This value may be null.
  • msg The message you would like logged. This value may be null.

return a positive value if the message was loggable (see isLoggable).

Implementation

static int v(String tag, String msg) {
  return $p.Log.v(tag.toJString(), msg.toJString());
}