wtf static method

int wtf(
  1. String tag,
  2. String msg
)

What a Terrible Failure: Report a condition that should never happen. The error will always be logged at level ASSERT with the call stack. Depending on system configuration, a report may be added to the DropBoxManager and/or the process may be terminated immediately with an error dialog.

  • tag Used to identify the source of a log message. It usually identifies the class or activity where the log call occurs. This value may be null.
  • msg The message you would like logged. This value may be null.

return a positive value if the message was loggable (see isLoggable).

Implementation

static int wtf(String tag, String msg) {
  return $p.Log.wtf(tag.toJString(), msg.toJString());
}