i static method
Send an info log message.
tagUsed to identify the source of a log message. It usually identifies the class or activity where the log call occurs. This value may be null.msgThe message you would like logged. This value may be null.
return a positive value if the message was loggable (see isLoggable).
Implementation
static int i(String tag, String msg) {
return $p.Log.i(tag.toJString(), msg.toJString());
}