println static method
Low-level logging call.
priorityint: The priority/type of this log message Value is assert_, error, warn, info, debug, or verbosetagUsed to identify the source of a log message. It usually identifies the class or activity where the log call occurs. This value may be null.messageString: The message you would like logged. This value cannot be null.
return a positive value if the message was loggable isLoggable.
Implementation
static int println(int priority, String tag, String msg) {
return $p.Log.println(priority, tag.toJString(), msg.toJString());
}